#!/usr/bin/python3
import dbus
import dbus.exceptions
import time

UDI = "/org/freedesktop/UDisks2/block_devices/sdb"
ESP_GUID = 'C12A7328-F81F-11D2-BA4B-00A0C93EC93B'

bus = dbus.SystemBus()

print("Getting Block proxy")
sdb_proxy = bus.get_object("org.freedesktop.UDisks2",
                           "/org/freedesktop/UDisks2/block_devices/sdb")

print("Calling Format")
sdb_proxy.Format('gpt', {},
                 dbus_interface="org.freedesktop.UDisks2.Block")

print("Getting a new Block proxy")
sdb_proxy = None
sdb_proxy2 = bus.get_object("org.freedesktop.UDisks2",
                           "/org/freedesktop/UDisks2/block_devices/sdb")


print("Calling CreatePartition")
try:
    sdb_proxy2.CreatePartition(0, 2500 * 2**20, ESP_GUID, "Test", {},
                 dbus_interface="org.freedesktop.UDisks2.PartitionTable",
                 signature='ttssa{sv}')
except dbus.exceptions.DBusException as e:
    # XXX: as of Debian Jessie, we often get errors while wiping
    # (Debian bug #767457). We ignore them as they are not fatal
    # for us... but we need to fix a few things later...
    if ('org.freedesktop.UDisks2.Error.Failed' in str(e) and
            'Error wiping newly created partition' in str(e)):
        print("Ignoring error %s" % e)
    else:
        raise

print("Getting a new Block proxy")
sdb_proxy2 = None
sdb_proxy3 = bus.get_object("org.freedesktop.UDisks2",
                           "/org/freedesktop/UDisks2/block_devices/sdb")

print("Calling Rescan")
sdb_proxy3.Rescan({}, dbus_interface="org.freedesktop.UDisks2.Block")

print("Getting Partition proxy")
sdb_proxy3 = None
sdb1_proxy = bus.get_object("org.freedesktop.UDisks2",
                           "/org/freedesktop/UDisks2/block_devices/sdb1")

print("Having a 3 seconds breather...")
time.sleep(3)
print("Calling SetType")
sdb1_proxy.SetType(ESP_GUID, {},
                 dbus_interface="org.freedesktop.UDisks2.Partition",
                 signature='sa{sv}')

print("Having a 3 seconds breather...")
time.sleep(3)
print("Calling SetName")
sdb1_proxy.SetName("Test", {},
                 dbus_interface="org.freedesktop.UDisks2.Partition",
                 signature='sa{sv}')

print("Done!")
